# wechaty-puppet [![Python 3.7](https://img.shields.io/badge/python-3.7+-blue.svg)](https://www.python.org/downloads/release/python-370/) [![PyPI Version](https://img.shields.io/pypi/v/wechaty-puppet?color=blue)](https://pypi.org/project/wechaty/) [![PyPI GitHub Actions](https://github.com/wechaty/python-wechaty-puppet/workflows/PyPI/badge.svg)](https://github.com/wechaty/python-wechaty-puppet/actions?query=workflow%3APyPI)

[![Powered by Wechaty](https://img.shields.io/badge/Powered%20By-Wechaty-brightgreen.svg)](https://github.com/wechaty/wechaty)

![chatie puppet](https://wechaty.github.io/wechaty-puppet/images/puppet-logo.jpg)

> Picture Credit: [https://www.shareicon.net](https://www.shareicon.net/puppet-marionette-puppeteer-puppet-variant-marionette-variant-665400)

[![PyPI Version](https://img.shields.io/pypi/v/wechaty-puppet?color=blue)](https://pypi.org/project/wechaty-puppet)
![PyPI - Downloads](https://img.shields.io/pypi/dm/wechaty-puppet?color=blue)

Abstract(Base) Class of Puppet Providers for Wechaty Framework.

This module is part of the [Python Wechaty](https://github.com/wechaty/python-wechaty) SDK.

Learn more at:

1. Wiki: <https://github.com/wechaty/wechaty/wiki/Puppet>
1. Issue: <https://github.com/wechaty/wechaty/issues/1167>

## Documentation

Wechaty Puppet Provider Interface Documentation can be found at <https://wechaty.github.io/wechaty-puppet/typedoc/classes/puppet.html>

> Automatica Generated by [TypeDoc](http://typedoc.org/)

## History

### master

### v0.0.1 (Mar 9, 2020)

1. Init the project
1. Published to PyPI

## Authors

- [@wj-Mcat](https://github.com/wj-Mcat) - Jingjing WU (吴京京)
- [@huan](https://github.com/huan) - ([李卓桓](http://linkedin.com/in/zixia)) zixia@zixia.net

## Copyright & License

* Code & Docs © 2020-now Huan LI (李卓桓) \<zixia@zixia.net\>
* Code released under the Apache-2.0 License
* Docs released under Creative Commons
